@@ -1,6 +1,6 @@
 from keap.REST.V1 import (
     AccountService, AffiliateService, AppointmentService, CampaignService, CompanyService,
-    ContactService, EmailService, FileService, LocaleService, MerchantService, NoteService, OpportunityService,
+    ContactService, EmailService, FileService, HookService, LocaleService, MerchantService, NoteService, OpportunityService,
     OrderService, ProductService, SettingService, SubscriptionService, TagService, TaskService, TransactionService,
     UserService)
 
@@ -16,6 +16,7 @@ class REST_V1:
         self.ContactService = ContactService(keap)
         self.EmailService = EmailService(keap)
         self.FileService = FileService(keap)
+        self.HookService = HookService(keap)
         self.LocaleService = LocaleService(keap)
         self.MerchantService = MerchantService(keap)
         self.NoteService = NoteService(keap)
@@ -28,3 +29,6 @@ class REST_V1:
         self.TaskService = TaskService(keap)
         self.TransactionService = TransactionService(keap)
         self.UserService = UserService(keap)
+
+    def test_connection(self):
+        return self.SettingService.get_application_status()
